@@ -9,11 +9,21 @@ def draw_line(origin: Vector, target: Vector, color: list = [1, 1, 1, 1]):
         color
     )
 
-def draw_cube(origin: Vector, width: float, color: list = [1, 1, 1, 1]):
-    draw_box(origin, width, width, width, color)
+
+def draw_points(points: list, color: list = [1, 1, 1, 1]):
+    for i, p in enumerate(points):
+        if i < len(points) - 1:
+            draw_line(p, points[i+1], color)
 
 
-def draw_box(origin: Vector, length: float, width: float, height: float, color: list = [1, 1, 1, 1]):
+def draw_cube(origin: Vector, width: float, color: list = [1, 1, 1, 1], centered=False):
+    draw_box(origin, width, width, width, color, centered)
+
+
+def draw_box(origin: Vector, length: float, width: float, height: float, color: list = [1, 1, 1, 1], centered=False):
+    if centered:
+        origin = origin.copy() - Vector((length * .5, width * .5, height * .5))
+
     c1: Vector = origin.copy()
     c2: Vector = origin.copy()
     c3: Vector = origin.copy()
